labeltools.label_vertical_moments_in_expr_with_pitch_numbers
============================================================

.. autofunction:: abjad.tools.labeltools.label_vertical_moments_in_expr_with_pitch_numbers.label_vertical_moments_in_expr_with_pitch_numbers
